# GetPixelColor

## A cross-platform python library for getting the color of a given pixel on screen.

 - Compatible with MacOS, Windows, and Linux.

Example:
> `print(getpixelcolor.pixel(500, 500))`
>  - prints a tuple with RGB values of the pixel at 500,500.\



